# History #

## 0.1.4 (2018-07-16) ##

* Add CylinderProblem
* Add background documentation
* Add desdeo-vis as extra dependency

## 0.1.3 (2018-06-18) ##

* Fix PyPI package

## 0.1.2 (2018-06-13) ##

* Improvements to automatically generated documentation
* Move river pollution example into `desdeo.problem.toy` module
* Allow solutions as well as objective functions to be obtained by adding ResultSet class
* Improvements to NIMBUS
  * Add missing NIMBUS scalarising functions
  * Add method to generate in-between solutions for NIMBUS
* Add RangeEstimator module for finding the nadir/ideal with a payoff table

## 0.1.1 (2018-05-21) ##

* Convert package description to use Markdown

## 0.1.0 (2018-04-25) ##

* First release
